@@ -1,8 +1,11 @@
+Encoding.default_external = Encoding::UTF_8
+Encoding.default_internal = Encoding::UTF_8
+
 require "pathname"
 require "cucumber/core"
 require "treetop"
 require "ripper"
-require "yajl"
+require "ffi_yajl"
 require "erubis"
 
 require_relative "foodcritic/chef"
