@@ -33,7 +33,7 @@ module FoodCritic
     end
 
     def to_s
-      @rules.sort { |a, b| a.code <=> b.code }.
+      @rules.sort_by(&:code).
         map { |r| r.to_s }.join("\n")
     end
 
